@@ -25,11 +25,11 @@ Test2::Aggregate - Aggregate tests
 
 =head1 VERSION
 
-Version 0.09_3
+Version 0.10_01
 
 =cut
 
-our $VERSION = '0.09_3';
+our $VERSION = '0.10_01';
 
 
 =head1 DESCRIPTION
@@ -62,6 +62,7 @@ that do not work.
         shuffle       => 0,                   # optional
         sort          => 0,                   # optional
         reverse       => 0,                   # optional
+        unique        => 1,                   # optional
         repeat        => 1,                   # optional, requires Test2::Plugin::BailOnFail for < 0
         slow          => 0,                   # optional
         override      => \%override,          # optional, requires Sub::Override
@@ -77,7 +78,7 @@ Runs the aggregate tests. Returns a hashref with stats like this:
       'test_no'   => 1,                 # numbering starts at 1
       'pass_perc' => 100,               # for single runs pass/fail is 100/0
       'timestamp' => '20190705T145043', # start of test
-      'time'      => '0.1732',          # only with stats_output
+      'time'      => '0.1732',          # seconds - only with stats_output
       'warnings'  => $STDERR            # only with test_warnings on non empty STDERR
     }
   };
@@ -122,13 +123,20 @@ Number of times to repeat the test(s) (default is 1 for a single run). If
 C<repeat> is negative, the tests will repeat until they fail (or produce a
 warning if C<test_warnings> is also set).
 
+=item * C<unique> (optional)
+
+Since v0.11 duplicate tests are by default removed from the running list as that
+could mess up the statistics output. You can still set it to a false value to allow
+duplicate tests to be in the list.
+
 =item * C<shuffle> (optional)
 
 Random order of tests if set to true. Will override C<sort>.
 
 =item * C<sort> (optional)
 
-Sort tests alphabetically if set to true.
+Sort tests alphabetically if set to true. Provides a way to fix the test order
+across systems.
 
 =item * C<reverse> (optional)
 
@@ -198,6 +206,8 @@ sub run_tests {
             if @dirs;
     }
 
+    $args{unique} = 1       if !defined $args{unique};
+    @tests = _uniq(@tests)  if $args{unique};
     @tests = reverse @tests if $args{reverse};
 
     if ($args{shuffle}) {
@@ -282,7 +292,8 @@ sub _run_tests {
 
             warn "$test->Test2::Aggregate\n" if $args->{test_warnings};
 
-            $stats{$test}{test_no}=++$count;
+            $count++;
+            $stats{$test}{test_no} ||= $count;
             $start = Time::HiRes::time() if $args->{stats_output};
             $stats{$test}{timestamp} = _timestamp();
 
@@ -349,6 +360,11 @@ sub _print_stats {
     close $fh unless $args->{stats_output} =~ /^-$/;
 }
 
+sub _uniq {
+    my %seen;
+    grep !$seen{$_}++, @_;
+}
+
 sub _timestamp {
     my ($s, $m, $h, $D, $M, $Y) = localtime(time);
     return sprintf "%04d%02d%02dT%02d%02d%02d", $Y+1900, $M+1, $D, $h, $m, $s;
